@@ -52,7 +52,6 @@ struct timeval timestamp_dev_status[MAX_DEVICES] = {0};
 struct timeval timestamp_ops_result[MAX_DEVICES] = {0};
 struct timeval timestamp_notify_mid[MAX_DEVICES] = {0};
 
-
 static gboolean gdbus_check_app_api_version(Biometric *object,
 											GDBusMethodInvocation *invocation,
 											int major, int minor, int function)
@@ -1599,12 +1598,13 @@ int main()
 	{
 		struct stat dir_stat;
 
-		stat(pid_dir_list[i], &dir_stat);
-		if (S_ISDIR(dir_stat.st_mode))
-		{
-			pid_dir = pid_dir_list[i];
-			break;
-		}
+        if (access(pid_dir_list[i], F_OK) == 0) {
+            stat(pid_dir_list[i], &dir_stat);
+            if (S_ISDIR(dir_stat.st_mode)) {
+                pid_dir = pid_dir_list[i];
+                break;
+            }
+        }
 	}
 	if (pid_dir == NULL)
 		pid_dir = "/";
